@@ -36,7 +36,6 @@
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtk.h>
-#include <gconf/gconf-client.h>
 
 #ifdef WITH_KBD_LAYOUT_INDICATOR
 #include <libgnomekbd/gkbd-indicator.h>
@@ -162,9 +161,7 @@ do_user_switch (GSLockPlug *plug)
                                    GDM_FLEXISERVER_ARGS);
 
         error = NULL;
-        res = gdk_spawn_command_line_on_screen (gdk_screen_get_default (),
-                                                command,
-                                                &error);
+        res = g_spawn_command_line_async (command, &error);
 
         g_free (command);
 
@@ -870,32 +867,6 @@ forward_key_events (GSLockPlug *plug)
         }
 }
 
-static void
-gs_lock_plug_get_preferred_height_for_width (GtkWidget *widget,
-                                             gint       width,
-                                             gint      *minimum,
-                                             gint      *natural)
-{
-        GTK_WIDGET_CLASS (gs_lock_plug_parent_class)->get_preferred_height_for_width (widget, width, minimum, natural);
-
-        /* if the dialog is wide fill out the height */
-        *minimum = MAX (*minimum, width / 1.6);
-        *natural = MAX (*natural, width / 1.6);
-}
-
-static void
-gs_lock_plug_get_preferred_width_for_height (GtkWidget *widget,
-                                             gint       height,
-                                             gint      *minimum,
-                                             gint      *natural)
-{
-        GTK_WIDGET_CLASS (gs_lock_plug_parent_class)->get_preferred_width_for_height (widget, height, minimum, natural);
-
-        /* if the dialog is tall fill out the width */
-        *minimum = MAX (*minimum, height * 1.3);
-        *natural = MAX (*natural, height * 1.3);
-}
-
 static void
 gs_lock_plug_set_logout_enabled (GSLockPlug *plug,
                                  gboolean    logout_enabled)
@@ -1087,8 +1058,6 @@ gs_lock_plug_class_init (GSLockPlugClass *klass)
         widget_class->style_set    = gs_lock_plug_style_set;
         widget_class->show         = gs_lock_plug_show;
         widget_class->hide         = gs_lock_plug_hide;
-        widget_class->get_preferred_width_for_height = gs_lock_plug_get_preferred_width_for_height;
-        widget_class->get_preferred_height_for_width = gs_lock_plug_get_preferred_height_for_width;
 
         klass->close = gs_lock_plug_close;
 
